@@ -19,11 +19,11 @@
 #define LIBPLACEBO_CONFIG_H_
 
 // Increased any time the library changes in a fundamental/major way.
-#define PL_MAJOR_VER 2
+#define PL_MAJOR_VER 3
 
 // Increased any time the API changes. (Note: Does not reset when PL_MAJOR_VER
 // is increased)
-#define PL_API_VER 72
+#define PL_API_VER 104
 
 // Increased any time a fix is made to a given API version.
 #define PL_FIX_VER (pl_fix_ver())
@@ -44,4 +44,7 @@ const char *pl_version(void);
 #define PL_HAVE_OPENGL 1
 
 
+// Extra compiler-specific stuff
+#define PL_DEPRECATED __attribute__((deprecated))
+
 #endif // LIBPLACEBO_CONTEXT_H_
